@@ -81,6 +81,11 @@ def get_id(element):
         return str(element)
 
 
+def strip_and_truncate_label(old_label: str, max_len: int):
+    label = str(old_label).strip("[]'")
+    return label if len(label) <= max_len else label[:max_len - 3] + '...'
+
+
 class GremlinNetwork(EventfulNetwork):
     """
     GremlinNetwork extends the Network class and uses the add_results method to parse two specific types of responses
@@ -93,14 +98,21 @@ class GremlinNetwork(EventfulNetwork):
     """
 
     def __init__(self, graph: MultiDiGraph = None, callbacks=None, label_max_length=DEFAULT_LABEL_MAX_LENGTH,
-                 group_by_property=T_LABEL, ignore_groups=False):
+                 group_by_property=T_LABEL, display_property=T_LABEL, ignore_groups=False):
         if graph is None:
             graph = MultiDiGraph()
-        self.label_max_length = label_max_length
+        if label_max_length < 3:
+            self.label_max_length = 3
+        else:
+            self.label_max_length = label_max_length
         try:
             self.group_by_property = json.loads(group_by_property)
         except ValueError:
             self.group_by_property = group_by_property
+        try:
+            self.display_property = json.loads(display_property)
+        except ValueError:
+            self.display_property = display_property
         self.ignore_groups = ignore_groups
         super().__init__(graph, callbacks)
 
@@ -280,31 +292,40 @@ class GremlinNetwork(EventfulNetwork):
             title = v.label
             vertex_dict = v.__dict__
             if not isinstance(self.group_by_property, dict):  # Handle string format group_by
-                if self.group_by_property in [T_LABEL, 'label']:  # this handles if it's just a string
+                if str(self.group_by_property) in [T_LABEL, 'label']:  # this handles if it's just a string
                     # This sets the group key to the label if either "label" is passed in or
                     # T.label is set in order to handle the default case of grouping by label
                     # when no explicit key is specified
                     group = v.label
-                elif self.group_by_property == 'id':
+                elif str(self.group_by_property) in [T_ID, 'id']:
                     group = v.id
                 else:
                     group = ''
             else:  # handle dict format group_by
                 try:
                     if str(v.label) in self.group_by_property:
-                        if self.group_by_property[str(v.label)]['groupby'] in [T_LABEL, 'label']:
+                        if self.group_by_property[str(v.label)] in [T_LABEL, 'label']:
                             group = v.label
+                        elif self.group_by_property[str(v.label)] in [T_ID, 'id']:
+                            group = v.id
                         else:
-                            group = vertex_dict[self.group_by_property[str(v.label)]['groupby']]
-                    elif str(v.id) in self.group_by_property:
-                        group = vertex_dict[self.group_by_property[str(v.id)]['groupby']]
+                            group = vertex_dict[self.group_by_property[str(v.label)]]
                     else:
                         group = ''
                 except KeyError:
                     group = ''
 
             label = title if len(title) <= self.label_max_length else title[:self.label_max_length - 3] + '...'
-            data = {'label': label, 'title': title, 'group': group, 'properties': {'id': node_id, 'label': title}}
+
+            if self.display_property in [T_ID, 'id']:
+                label = str(node_id)
+            elif isinstance(self.display_property, dict):
+                try:
+                    if self.display_property[title] in [T_ID, 'id']:
+                        label = str(node_id)
+                except KeyError:
+                    pass
+            data = {'label': str(label).strip("[]'"), 'title': title, 'group': group, 'properties': {'id': node_id, 'label': title}}
         elif type(v) is dict:
             properties = {}
             title = ''
@@ -315,19 +336,27 @@ class GremlinNetwork(EventfulNetwork):
             # Since it is needed for checking for the vertex label's desired grouping behavior in group_by_property
             if T.label in v.keys():
                 title = str(v[T.label])
-                label = title if len(title) <= self.label_max_length else title[:self.label_max_length - 3] + '...'
+                label = strip_and_truncate_label(title, self.label_max_length)
             for k in v:
                 if str(k) == T_ID:
                     node_id = str(v[k])
                 properties[k] = v[k]
                 if isinstance(self.group_by_property, dict):
                     try:
-                        if str(k) == self.group_by_property[title]['groupby']:
+                        if str(k) == self.group_by_property[title]:
                             group = str(v[k])
                     except KeyError:
-                        continue
+                        pass
                 elif str(k) == self.group_by_property:
                     group = str(v[k])
+                if isinstance(self.display_property, dict):
+                    try:
+                        if str(k) == self.display_property[title]:
+                            label = strip_and_truncate_label(str(v[k]), self.label_max_length)
+                    except KeyError:
+                        continue
+                elif str(k) == self.display_property:
+                    label = strip_and_truncate_label(str(v[k]), self.label_max_length)
 
             # handle when there is no id in a node. In this case, we will generate one which
             # is consistently regenerated so that duplicate dicts will be reduced to the same vertex.
@@ -339,7 +368,8 @@ class GremlinNetwork(EventfulNetwork):
             if title == '':
                 for key in v:
                     title += str(v[key])
-                label = title if len(title) <= self.label_max_length else title[:self.label_max_length - 3] + '...'
+                if label == '':
+                    label = title if len(title) <= self.label_max_length else title[:self.label_max_length - 3] + '...'
 
             data = {'properties': properties, 'label': label, 'title': title, 'group': group}
         else:
